@@ -20,6 +20,16 @@ type TipoAtendimentoAvulsoInfraestruturaType = Literal[
     "Treinamento",
 ]
 
+type TipoOsSistemasType = Literal[
+    "Implementação",
+    "Manutenção Corretiva",
+    "Monitoramento",
+    "Mudança de Escopo",
+    "Suporte Infraestrutura",
+    "Suporte Sistema",
+    "Treinamento",
+]
+
 
 type OrigemAtendimentoAvulsoSistemasType = Literal[
     "E-mail",
@@ -31,6 +41,19 @@ type OrigemAtendimentoAvulsoSistemasType = Literal[
     "SAE",
 ]
 
+
+type OrigemOsSistemasType = Literal[
+    "E-mail",
+    "Pessoalmente",
+    "Teams",
+    "Telefone",
+    "WhatsApp",
+    "Plantão",
+    "SAE",
+    "SATIC",
+    "Siga",
+]
+
 type SistemasType = Literal[
     "Abaris",
     "Administrar Permissões e Acesso - Segurança",
@@ -168,6 +191,8 @@ type SistemasType = Literal[
     "SGA - Pesquisa MPHU (INATIVO)",
 ]
 
+type teste = ...
+
 type CategoriasInfraestruturaType = Literal[
     "AD - Alterar Configuração do Domínio",
     "AD - Criar usuário",
@@ -523,4 +548,76 @@ type TipoAtendimentosOSType = Literal[
     "Requisição",
 ]
 
+type LinguagemOsSistemasType = Literal[
+    "C#",
+    "Fox",
+    "SQL",
+    "ASP.Net",
+    "Access",
+    "PHP",
+    "Extrator de Dados",
+    "MV Painel de Indicadores",
+    "MV Editor",
+    "Gerador de Relatórios",
+    "Gerador de Cubos",
+    "Power BI",
+    "Gerador de Tela",
+    "Editor de Regra",
+    "Delphi",
+    "Script SO",
+    "Node.js",
+    "Senior - Gerador de visão dinâmica",
+    "Analytics",
+]
+
+
+type OsInternaSistemasType = Literal[
+    "Sim",
+    "Não",
+]
+
+type StatusOsType = Literal[
+    "Concluída",
+    "Concluída por Encaminhamento",
+    "Concluída por substituição",
+    "Em Atendimento",
+    "Em Implantação",
+    "Em Teste",
+    "Não Planejada",
+    "Pendente-Aprovação",
+    "Pendente-Atendimento",
+    "Pendente-Atualização de Versão",
+    "Pendente-AVA",
+    "Pendente-Consultoria",
+    "Pendente-Equipe Infraestrutura",
+    "Pendente-Equipe Manutenção",
+    "Pendente-Fornecedor",
+    "Pendente-Help-Desk",
+    "Pendente-Liberação",
+    "Pendente-Marketing",
+    "Pendente-Sist. Acadêmicos",
+    "Pendente-Sist. Administrativos",
+    "Pendente-Teste",
+    "Pendente-Usuário",
+    "Solicitação em Aprovação",
+    "Cancelada-Usuário",
+    "Cancelamento DTD | Arquivado",
+]
+
+type CriticidadeOsType = Literal[
+    "Nenhuma",
+    "Baixa",
+    "Média",
+    "Alta",
+]
+
+type PrioridadeUsuarioOsType = Literal[
+    "Nenhuma",
+    "Urgente",
+    "Alta",
+    "Média",
+    "Baixa",
+]
+
+
 type TransportType = Literal["http", "stdio"]
