@@ -240,6 +240,17 @@ TIPO_TO_NUMBER_ATENDIMENTO_AVULSO_INFRAESTRUTURA = {
     "Treinamento": 18,
 }
 
+# Listagem para a Combo Tipos para OS.
+TIPO_TO_NUMBER_OS_SISTEMAS = {
+    "Implementação": 2,
+    "Manutenção Corretiva": 3,
+    "Monitoramento": 21,
+    "Mudança de Escopo": 20,
+    "Suporte Infraestrutura": 13,
+    "Suporte Sistema": 1,
+    "Treinamento": 5,
+}
+
 # Listagem para a Combo Origem.
 ORIGEM_TO_NUMBER = {
     "E-mail": 1,
@@ -251,6 +262,20 @@ ORIGEM_TO_NUMBER = {
     "SAE": 11,
 }
 
+# Listagem para a Combo Origem para OS.
+ORIGEM_OS_TO_NUMBER = {
+    "E-mail": 1,
+    "Pessoalmente": 2,
+    "Teams": 3,
+    "Telefone": 4,
+    "WhatsApp": 5,
+    "Plantão": 7,
+    "SAE": 11,
+    "SATIC": 8,
+    "Siga": 6,
+}
+
+
 # Listagem para a Combo Sistema.
 SISTEMA_TO_NUMBER = {
     "Abaris": 285,
@@ -511,33 +536,33 @@ EQUIPE_TO_NUMBER = {
 
 # TODO(Fernando): Atualizar os números quando forem definidos.
 EQUIPE_INFRAESTRUTURA_TO_NUMBER = {
-    "Administador de Banco de Dados": 999999,
-    "Gerenciamento de Redes": 999999,
-    "Gerenciamento de Redes - Linux": 999999,
-    "Gerenciamento de Redes - Windows": 999999,
-    "Help-Desk - Aeroporto": 999999,
-    "Help-Desk - Ambulatório": 999999,
-    "Help-Desk - Araxá": 999999,
-    "Help-Desk - Centro": 999999,
-    "Help-Desk - HR": 999999,
-    "Help-Desk - HVU": 999999,
-    "Help-Desk - IMM": 999999,
-    "Help-Desk - MPHU": 999999,
-    "Help-Desk - NPG": 999999,
-    "Help-Desk - UPA Mirante": 999999,
-    "Help-Desk - UPA São Benedito": 999999,
-    "Help-Desk - Via Centro": 999999,
-    "Help-Desk - Vila Gávea": 999999,
-    "LIAE - Aeroporto": 999999,
-    "LIAE - Via Centro": 999999,
-    "Ouvidoria / Telefonia": 999999,
-    "Proteção de dados": 999999,
-    "Publicação AVA": 999999,
+    "Administador de Banco de Dados": "DBA",
+    "Gerenciamento de Redes": "REDES",
+    "Gerenciamento de Redes - Linux": "LINUX",
+    "Gerenciamento de Redes - Windows": "WINDOWS",
+    "Help-Desk - Aeroporto": "Help Aero",
+    "Help-Desk - Ambulatório": "Help Amb",
+    "Help-Desk - Araxá": "Help Ara",
+    "Help-Desk - Centro": "Help Cen",
+    "Help-Desk - HR": "Help HR",
+    "Help-Desk - HVU": "Help HVU",
+    "Help-Desk - IMM": "Help IMM",
+    "Help-Desk - MPHU": "Help MPHU",
+    "Help-Desk - NPG": "Help NPG",
+    "Help-Desk - UPA Mirante": "Help UPA_M",
+    "Help-Desk - UPA São Benedito": "Help UPASB",
+    "Help-Desk - Via Centro": "Help Mar",
+    "Help-Desk - Vila Gávea": "Help Vila",
+    "LIAE - Aeroporto": "LIAE Aero",
+    "LIAE - Via Centro": "LIAE Mar",
+    "Ouvidoria / Telefonia": "OUVIDORIA",
+    "Proteção de dados": "DPO",
+    "Publicação AVA": "Pub-AVA",
 }
 
 # Listagem para a Combo Projeto.
 PROJETO_TO_NUMBER = {
-    "Adequações para ONA 2022": 107,
+    "Adequações para ONA 2022": (107),
     "Adequações para ONA 2024": 155,
     "Adequações para ONA 2025": 198,
     "Aditivos ao contrato dos alunos": 125,
@@ -697,6 +722,84 @@ PROJETO_TO_NUMBER = {
 }
 
 
+# Listagem para a Combo Tipos para OS.
+LINGUAGEM_TO_NUMBER_OS_SISTEMAS = {
+    "C#": 1,
+    "Fox": 2,
+    "SQL": 3,
+    "ASP.Net": 4,
+    "Access": 5,
+    "PHP": 6,
+    "Extrator de Dados": 7,
+    "MV Painel de Indicadores": 8,
+    "MV Editor": 9,
+    "Gerador de Relatórios": 10,
+    "Gerador de Cubos": 11,
+    "Power BI": 18,
+    "Gerador de Tela": 12,
+    "Editor de Regra": 13,
+    "Delphi": 14,
+    "Script SO": 15,
+    "Node.js": 23,
+    "Senior - Gerador de visão dinâmica": 24,
+    "Analytics": 20,
+}
+
+# Listagem para a Combo Interna para OS.
+OS_INTERNA_OS_TO_NUMBER = {
+    "Sim": 1,
+    "Não": 0,
+}
+
+
+# Listagem para a Combo Status para OS.
+STATUS_OS_TO_NUMBER = {
+    "Concluída": 8,
+    "Concluída por Encaminhamento": 9,
+    "Concluída por substituição": 10,
+    "Em Atendimento": 3,
+    "Em Implantação": 7,
+    "Em Teste": 5,
+    "Não Planejada": 1,
+    "Pendente-Aprovação": 96,
+    "Pendente-Atendimento": 2,
+    "Pendente-Atualização de Versão": 93,
+    "Pendente-AVA": 94,
+    "Pendente-Consultoria": 92,
+    "Pendente-Equipe Infraestrutura": 95,
+    "Pendente-Equipe Manutenção": 88,
+    "Pendente-Fornecedor": 97,
+    "Pendente-Help-Desk": 87,
+    "Pendente-Liberação": 6,
+    "Pendente-Marketing": 89,
+    "Pendente-Sist. Acadêmicos": 90,
+    "Pendente-Sist. Administrativos": 91,
+    "Pendente-Teste": 4,
+    "Pendente-Usuário": 98,
+    "Solicitação em Aprovação": 101,
+    "Cancelada-Usuário": 100,
+    "Cancelamento DTD | Arquivado": 99,
+}
+
+
+# Listagem para a Combo Criticidade para OS.
+CRITICIDADE_OS_TO_NUMBER = {
+    "Nenhuma": 0,
+    "Baixa": 1,
+    "Média": 2,
+    "Alta": 3,
+}
+
+# Listagem para a Combo Criticidade para OS.
+PRIORIDADE_USUARIO_OS_TO_NUMBER = {
+    "Nenhuma": 0,
+    "Urgente": 1,
+    "Alta": 2,
+    "Média": 3,
+    "Baixa": 4,
+}
+
+
 def _safe_langfuse_prompt(key: str, default: str = "") -> str:
     try:
         # langfuse may be None if not installed or not initialized
@@ -716,3 +819,7 @@ TEAMS_CLIENT_ID = ""
 TEAMS_CLIENT_SECRET = ""
 
 TEAMS_TENANT_ID = ""
+
+PACKAGE_NAME = "siga-mcp"
+
+DEFAULT_PORT = 8000
