@@ -1,11 +1,29 @@
 def docs() -> str:
-    return f"""
+    return """
 Insere um novo atendimento avulso no sistema SIGA.
 
+**INSTRUÇÃO PARA O AGENTE IA:**
+ANTES de executar esta função de inserção:
+1. MOSTRE ao usuário TODAS as informações que serão criadas/inseridas no sistema
+2. APRESENTE os dados de forma clara e organizada (datas, descrição, tipo, origem, sistema, equipe, projeto, analista, etc.)
+3. PEÇA confirmação explícita do usuário: "Confirma a criação? (sim/não)"
+4. SÓ EXECUTE esta função se o usuário confirmar explicitamente
+5. Se o usuário não confirmar, cancele a operação e informe que foi cancelada
+
 Esta função cria um novo registro de atendimento avulso independente de qualquer Ordem de Serviço,
 incluindo informações como datas, descrição, tipo, origem, sistema, equipe e projeto.
 Realiza validação de todos os campos obrigatórios e conversão automática de datas.
 
+**ORIENTAÇÃO PARA SOLICITAÇÕES GENÉRICAS:**
+Quando o usuário solicitar "inserir/criar um atendimento" sem especificar o tipo:
+1. **Perguntar qual tipo**: Atendimento OS, Atendimento Avulso Sistemas, ou Atendimento Avulso Infraestrutura
+2. **Se escolher "Avulso"**: Perguntar se é de Sistemas ou Infraestrutura
+3. **Depois de definir o tipo**: Direcionar para a função específica correspondente
+
+Esta função é específica para **Atendimentos Avulso Sistemas**. Para outros tipos, use:
+- `inserir_atendimentos_os` (vinculados a OS)  
+- `inserir_atendimento_avulso_infraestrutura` (área de Infraestrutura)
+
 **Endpoint utilizado:** `inserirAtendimentoAvulsoSigaIA`
 
 **Estrutura do XML retornado:**
@@ -33,6 +51,43 @@ Realiza validação de todos os campos obrigatórios e conversão automática de
 </erro_validacao>
 ```
 
+**Em caso de erro de validação (analista obrigatório):**
+```xml
+<erro_validacao sistema="SIGA" funcao="inserir_atendimento_avulso_sistemas">
+    <erro sistema="SIGA">
+        <status>erro</status>
+        <tipo_erro>analista_obrigatorio</tipo_erro>
+        <campo_invalido>codigo_analista</campo_invalido>
+        <valor_informado>0</valor_informado>
+        <mensagem>Campo 'codigo_analista' é obrigatório e deve ser 'CURRENT_USER' ou um número válido maior que zero. Valor informado: 0</mensagem>
+    </erro>
+</erro_validacao>
+```
+
+**Em caso de erro (dados inválidos):**
+```xml
+<atendimentos_avulsos dataIni="2024-01-15 09:00:00" dataFim="2024-01-15 17:00:00"
+                        matSolicitante="123456" tipo="19" descricao="Descrição"
+                        origem="3" equipe="AVA" analista="789" projeto="67" sistema="271">
+    <atendimento_avulso sistema="SIGA">
+        <status>erro</status>
+        <mensagem>Não foi possível salvar o atendimento avulso. Verifique as informações digitadas.</mensagem>
+    </atendimento_avulso>
+</atendimentos_avulsos>
+```
+
+**Em caso de outros erros:**
+```xml
+<atendimentos_avulsos dataIni="2024-01-15 09:00:00" dataFim="2024-01-15 17:00:00"
+                        matSolicitante="123456" tipo="19" descricao="Descrição"
+                        origem="3" equipe="AVA" analista="789" projeto="67" sistema="271">
+    <atendimento_avulso sistema="SIGA">
+        <status>erro</status>
+        <mensagem>Erro ao gravar o atendimento avulso. Tente novamente.</mensagem>
+    </atendimento_avulso>
+</atendimentos_avulsos>
+```
+
 Args:
     data_inicio (str): Data e hora de início do atendimento avulso.
         Aceita formatos de data ou palavras-chave como "hoje", "agora", "ontem"
@@ -40,7 +95,8 @@ Args:
         Aceita formatos de data ou palavras-chave como "hoje", "agora", "ontem"
     matricula_solicitante (str | Literal["CURRENT_USER"]): Matrícula do usuário que está solicitando o atendimento avulso
     descricao_atendimento (str): Descrição detalhada do atendimento avulso a ser realizado
-    codigo_analista (str | Literal["CURRENT_USER"]): Matrícula do analista/usuário responsável pelo atendimento avulso
+    codigo_analista (str | Literal["CURRENT_USER"]): **[OBRIGATÓRIO]** Matrícula do analista/usuário responsável pelo atendimento avulso.
+    Deve ser "CURRENT_USER" ou um número válido maior que zero. Não aceita valores vazios, "0" ou não-numéricos.
     tipo (Literal): Tipo do atendimento avulso, deve ser um dos valores válidos:
         - "Suporte Sistema" (código 1)
         - "Manutenção de Banco" (código 10)
@@ -362,7 +418,7 @@ Args:
 Returns:
     str: XML formatado contendo:
         - Em caso de sucesso: confirmação da inserção com status "sucesso"
-        - Em caso de erro de validação: detalhes do erro com valores válidos para o campo inválido
+        - Em caso de erro de validação: detalhes do erro (tipo inválido, analista obrigatório, origem inválida, etc.)
         - Em caso de erro de API: mensagem de erro específica
         - Em caso de erro interno: mensagem de erro genérica
 
@@ -406,7 +462,19 @@ Examples:
     ...     tipo="Tipo Inexistente"  # Erro!
     ... )
 
+    >>> # Exemplo com codigo_analista inválido (retorna erro)
+    >>> xml = await inserir_atendimento_avulso_sistemas(
+    ...     data_inicio="2024-01-15 09:00:00",
+    ...     data_fim="2024-01-15 17:00:00",
+    ...     matricula_solicitante="123456",
+    ...     descricao_atendimento="Teste",
+    ...     codigo_analista="0",  # Erro!
+    ...     tipo="Atividade Interna"
+    ... )
+
 Notes:
+    - **DIFERENCIAÇÃO DE FUNÇÃO**: Esta função cria novos atendimentos avulso sistemas. Para editar, use editar_atendimento_avulso_sistemas 
+    - **VALIDAÇÃO OBRIGATÓRIA**: Campo codigo_analista deve ser "CURRENT_USER" ou um número válido maior que zero (não aceita valores vazios, "0" ou não-numéricos)
     - Esta função é específica para ÁREA SISTEMAS (área=1)
     - A função realiza validação case-insensitive de todos os campos (tipo, origem, sistema, equipe, projeto)
     - As datas são automaticamente convertidas usando converter_data_siga com manter_horas=True
